Defines VibeNode, a self-contained processing unit.
A VibeNode is like a single worker in the system’s factory. It has its own
task queue and a pool of threads to execute those tasks. It’s designed to be
self-managing, automatically adjusting the number of active threads based on
its current workload (pressure).
Structs
- Vibe
Node - A processing unit that executes tasks.
Enums
- Pressure
Level - A qualitative measure of a node’s current workload.