pub struct LocalStats { /* private fields */ }Expand description
Tracks performance statistics for a single VibeNode.
This struct uses atomic counters and rolling windows to provide insights into the performance and workload of an individual node.
Implementations
Sourceimpl LocalStats
impl LocalStats
Sourcepub fn task_submitted(&self)
pub fn task_submitted(&self)
Increments the count of submitted tasks.
Sourcepub fn record_task_outcome(&self, duration: u64, success: bool)
pub fn record_task_outcome(&self, duration: u64, success: bool)
Records the outcome of a finished task.