pub struct VibeSystem { /* private fields */ }Expand description
The main entry point for the simple parallel execution system.
Implementations
Sourceimpl VibeSystem
impl VibeSystem
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new VibeSystem with sensible default settings.
This initializes the background worker pools and load balancer.