pub struct Job<T> { /* private fields */ }Expand description
A handle to a job that is running in the background.
Implementations
Sourceimpl<T> Job<T>
impl<T> Job<T>
Sourcepub fn get(self) -> T
pub fn get(self) -> T
Waits for the job to finish and returns its result.
Panics
Panics if the job failed (e.g., the user’s function panicked) or if the system was shut down before the job could complete.